from plone.app.content.batching import Batch

import interfaces

def createPloneBatch(batch, navlistsize=5):
    """ Create Plone user interface compatible batch presentation from our batch implementation

    Plone batch has user interface functionalities built in. Our batch do not make such assumptions.

    @param: batch collective.batch.Batch
    @param navlistsize: How many options to display in the page selector
    @return: plone.app.content.batching.Batch instance
    """

    assert interfaces.IBatch.providedBy(batch), "Got object:" + str(batch)

    assert batch.totalCount > 0, "Batch didn't contain any items"

    assert batch.hasSeveralBatches(), "The result set has only one batch"

    plone_batch = Batch(batch, batch.batchSize, batch.getPageNumber(), navlistsize)

    # Check that we didn't create an invalid batch...
    try:
        # plone_batch page indexes are one based
        assert plone_batch.pagenumber >= plone_batch.firstpage-1
        assert plone_batch.pagenumber <= plone_batch.lastpage, "Got page no %d last page is %d" % (plone_batch.pagenumber, plone_batch.lastpage)
    except AssertionError:
        # put in your pdb here
        raise

    return plone_batch